<!-- markdownlint-disable -->

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\call_later.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.call_later`





---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\call_later.py#L7"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `call_later`

```python
call_later(what, msec: int = 1)
```

call the given function after a specified delay 




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
